@@ -2,5 +2,5 @@
 # 'tools::package_native_routine_registration_skeleton()' generates the required
 # registration info for the 'run_testthat_tests' symbol.
 (function() {
-  .Call("run_testthat_tests", PACKAGE = "ANN2")
+  .Call("run_testthat_tests", FALSE, PACKAGE = "ANN2")
 })
